############################
Python API and CLI reference
############################

AROSICS offers two interfaces.

| 1. You can use AROSICS as a **Python package**
|    (e.g., to be embed it into your Python code):

   .. toctree::
       :maxdepth: 4

       modules.rst


| 2. You can use AROSICS from the **command line**
|    (you don't need to be familiar with Python in that case):

   .. toctree::
       :maxdepth: 4

       cli_reference.rst
